/**
  *  \file client/tiles/basemineral.cc
  *
  *  (c) 2001-2013 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/tiles/basemineral.h"
#include "game/planet.h"
#include "cpluslib/format.h"
#include "util/nls.h"
#include "ui/uiglobal.h"

/**************************** WBaseMineralTile ***************************/

WBaseMineralTile::WBaseMineralTile(GObjectSelection& selection)
    : WObjectSelectionObserverTile(GfxPoint(315, font_heights[FONT_NORMAL] * 4), selection)
{ }

void
WBaseMineralTile::drawBaseMineralTile(UIAbstractTableWriter& tw)
{
    GPlanet* p = dynamic_cast<GPlanet*>(getCurrentObject());
    if (!p)
        return;

    tw.newLColumn();
    tw.writeFixedCell(UIColor::tc_Static, _("Neu:"));
    tw.writeFixedCell(UIColor::tc_Static, _("Tri:"));
    tw.writeFixedCell(UIColor::tc_Static, _("Dur:"));
    tw.writeFixedCell(UIColor::tc_Static, _("Mol:"));

    tw.newRColumn(fonts[FONT_NORMAL]->getTextWidth("999,999 kt"));
    tw.writeVariableCell(UIColor::tc_Green, format("%d kt", p->getCargo(el_Neutronium)));
    tw.writeVariableCell(UIColor::tc_Green, format("%d kt", p->getCargo(el_Tritanium)));
    tw.writeVariableCell(UIColor::tc_Green, format("%d kt", p->getCargo(el_Duranium)));
    tw.writeVariableCell(UIColor::tc_Green, format("%d kt", p->getCargo(el_Molybdenum)));

    tw.newLColumn(5);

    tw.newLColumn();
    tw.writeFixedCell(UIColor::tc_Static, _("Money:"));
    tw.writeFixedCell(UIColor::tc_Static, _("Supplies:"));
    tw.writeFixedCell(UIColor::tc_Static, string_t());
    tw.writeFixedCell(UIColor::tc_Static, string_t());

    tw.newRColumn(fonts[FONT_NORMAL]->getTextWidth("999,999 mc"));
    tw.writeVariableCell(UIColor::tc_Green, format("%d mc", p->getCargo(el_Money)));
    tw.writeVariableCell(UIColor::tc_Green, format("%d kt", p->getCargo(el_Supplies)));
    tw.writeVariableCell(UIColor::tc_Static, string_t());
    tw.writeVariableCell(UIColor::tc_Static, string_t());

    tw.finish();
}

void
WBaseMineralTile::drawData(GfxCanvas& can)
{
    GfxContext ctx;
    ctx.useCanvas(can).useColorScheme(getSkin());
    UITableWriter tw(ctx, getInnerSize(5, 0), FONT_NORMAL);
    drawBaseMineralTile(tw);
}
