/**
  *  \file int/if/objif.cc
  *  \brief Interpreter Game Interface: Common Object Methods
  *
  *  (c) 2001-2013 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "int/if/objif.h"
#include "int/if/ifutil.h"
#include "game/obj.h"
#include "int/interror.h"
#include "int/args.h"

/** Constructor.
    \param obj Object to operate on
    \param call Function to call */
IntObjectProcedureValue::IntObjectProcedureValue(GObject& obj, GUniverse& univ, call_t call)
    : obj(obj), univ(univ), call_function(call)
{ }

/** Destructor. */
IntObjectProcedureValue::~IntObjectProcedureValue()
{ }

// IntCallableValue:
IntValue*
IntObjectProcedureValue::call(IntExecutionContext& exc, IntArgBlock& args)
{
    call_function(obj, univ, exc, args);
    return 0;
}

bool
IntObjectProcedureValue::isProcedureCall()
{
    return true;
}

// IntValue:
string_t
IntObjectProcedureValue::toString(bool /*readable*/)
{
    return "#<obj-procedure>";
}

void
IntObjectProcedureValue::store(IntTagNode&, Stream&)
{
    throw IntError::notSerializable();
}

IntValue*
IntObjectProcedureValue::clone()
{
    return new IntObjectProcedureValue(obj, univ, call_function);
}

/******************************* Functions *******************************/

/** Implementation of the "Mark" command.
    Syntax: 'Mark [flag]' */
void
IFObjMark(GObject& obj, GUniverse& /*univ*/, IntExecutionContext& /*exc*/, IntArgBlock& args)
{
    args.checkArgumentCount(0, 1);

    bool state = true;
    checkBoolArg(state, args.getNext());
    obj.setIsMarked(state);
}

/** Implementation of the "Unmark" command.
    Syntax: 'Unmark' */
void
IFObjUnmark(GObject& obj, GUniverse& /*univ*/, IntExecutionContext& /*exc*/, IntArgBlock& args)
{
    args.checkArgumentCount(0);
    obj.setIsMarked(false);
}
