/**
  *  \file ui/widgets/abstractcheckbox.h
  *  \brief UIAbstractCheckbox base class
  *
  *  (c) 2001-2013 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_UI_WIDGETS_ABSTRACTCHECKBOX_H
#define PCC_V2_UI_WIDGETS_ABSTRACTCHECKBOX_H

#include "ui/widgets/abstractbutton.h"
#include "gfx/pixmap.h"
#include "cpluslib/smartptr.h"

/** \class UIAbstractCheckbox
    \brief Abstract Checkbox

    This module provides drawing and event handling for an abstract
    checkbox. Descendants have to override getPixmap() and click() to
    provide the actual policy. */
class UIAbstractCheckbox : public UIAbstractButton {
    string_t name;
 protected:
    UIAbstractCheckbox(int id, string_t name, UIKey key);
    ~UIAbstractCheckbox();

    virtual Ptr<GfxPixmap> getPixmap() = 0;
    virtual void click(int) = 0;
 public:
    void drawContent(GfxCanvas& can);
    void getLayoutInfo(LayoutInfo& info);
    void onStateChange(int state, bool enabled);
    bool handleEvent(const UIEvent& e, bool second_pass);
};

#endif
